American Institute of Steel Construction Python Implementation

This package implements various chapters of the AISC Manual related
to the capacity calculations for specific member types. 

Specific chapters of the AISC Manual deal with the capacity of certain
member types in a formulaic way that lends itself to developing 
a package of functions for easy reuse. 

This package implements functions for the following chapters of the
AISC Manual:

Chapter B</br>
Chapter D</br>
Chapter E</br>
Chapter F</br>
Chapter G</br>
Chapter H</br>
Chapter I</br>

The following versions of the AISC Manual that are currently 
included are:

13th Edition</br>
14th Edition</br>
15th Edition</br>

Note: Bolted connection design covered in Chapter J is implemented
in a separate package. 
